@@ -1,12 +1,7 @@
 from django.contrib import admin
 from djangoldp.admin import DjangoLDPAdmin
-from .models import (
-    Component,
-    Parameter,
-    ComponentScriptTag,
-    Package,
-    ServerParameter,
-)
+
+from .models import Component, ComponentScriptTag, Package, Parameter, ServerParameter
 
 
 class EmptyAdmin(admin.ModelAdmin):
